@@ -1128,25 +1128,29 @@ class TestJobCommands(BaseTest):
                 assert len(result) == 1
                 assert result[0] == Path(f1.name)
 
-                with open('input_file1.txt', 'w') as f2:
-                    file_list_string = f1.name + "," + f2.name
-                    result = get_file_list(file_list_string)
-                    assert len(result) == 2
-                    assert Path(f1.name) in result
-                    assert Path(f2.name) in result
+                with open('file_without_extension', 'w') as f2:
+                    result = get_file_list(f2.name)
+                    assert len(result) == 1
+                    assert result[0] == Path(f2.name)
 
-                    with open('input_file2.py', 'w') as f3:
-                        with open('temp.txt', 'w') as f4:
+                    with open('input_file1.txt', 'w') as f3:
+                        file_list_string = f1.name + "," + f3.name
+                        result = get_file_list(file_list_string)
+                        assert len(result) == 2
+                        assert Path(f1.name) in result
+                        assert Path(f3.name) in result
+
+                        with open('input_file2.py', 'w') as f4, open('temp.txt', 'w') as f5:
                             result = get_file_list("input*")
                             assert len(result) == 3
                             assert Path(f1.name) in result
-                            assert Path(f2.name) in result
                             assert Path(f3.name) in result
+                            assert Path(f4.name) in result
 
                             result = get_file_list('input*.txt')
                             assert len(result) == 2
                             assert Path(f1.name) in result
-                            assert Path(f2.name) in result
+                            assert Path(f3.name) in result
 
     def test_get_file_list_from_tree_get_directory(self):
         try:
@@ -1189,8 +1193,8 @@ class TestJobCommands(BaseTest):
     def test_get_file_list_from_tree_get_file_with_wildcards(self):
         try:
             dir, sub_dir, dir_files_list, sub_dir_files_list = self._create_files_tree()
-            file = open(os.path.join(dir, f'test.txt'), 'w')
-            dir_files_list.append(Path(file.name))
+            with open(os.path.join(dir, f'test.txt'), 'w') as file:
+                dir_files_list.append(Path(file.name))
 
             result = get_file_list(str(dir) + '/file*')
             assert len(result) == 10
@@ -1246,12 +1250,12 @@ class TestJobCommands(BaseTest):
             temp_sub_dir.mkdir()
             temp_dir_files_list = list()
             for x in range(5):
-                file = open(os.path.join(temp_dir, f'file{x}.txt'), 'w')
-                temp_dir_files_list.append(Path(file.name))
+                with open(os.path.join(temp_dir, f'file{x}.txt'), 'w') as file:
+                    temp_dir_files_list.append(Path(file.name))
             temp_sub_dir_files_list = list()
             for x in range(5,10):
-                file = open(os.path.join(temp_sub_dir, f'file{x}.txt'), 'w')
-                temp_sub_dir_files_list.append(Path(file.name))
+                with open(os.path.join(temp_sub_dir, f'file{x}.txt'), 'w') as file:
+                    temp_sub_dir_files_list.append(Path(file.name))
             return temp_dir, temp_sub_dir, temp_dir_files_list, temp_sub_dir_files_list
         except Exception:
             if Path(temp_dir).exists():
